use std::collections::HashMap;

// todo : implement cache feature
#[derive(Debug)]
pub struct ModelCache {
    cache: HashMap<String, HashMap<String, mongodb::bson::Document>>,
}

impl ModelCache {
    pub fn new() -> Self {
        Self {
            cache: HashMap::new(),
        }
    }

    pub fn insert(&mut self, col: &str, id: &str, model: mongodb::bson::Document) {
        let collection = self
            .cache
            .entry(col.to_string())
            .or_insert_with(HashMap::new);
        collection.insert(id.to_string(), model);
    }

    pub fn invalidate(&mut self, col: &str, id: &str) {
        if let Some(collection) = self.cache.get_mut(col) {
            collection.remove(id);
            if collection.is_empty() {
                self.cache.remove(col);
            }
        }
    }

    pub fn get(&self, col: &str, id: &str) -> Option<&mongodb::bson::Document> {
        self.cache
            .get(col)
            .and_then(|collection| collection.get(id))
    }
}
